@@ -293,9 +293,15 @@ class BoundReferenceSetBase(object):
     def __iter__(self):
         return self.find().__iter__()
 
+    def __getitem__(self, index):
+        return self.find().__getitem__(index)
+
     def __contains__(self, item):
         return item in self.find()
 
+    def is_empty(self):
+        return self.find().is_empty()
+
     def first(self, *args, **kwargs):
         return self.find(*args, **kwargs).first()
 
